public BlockTermsReader(TermsIndexReaderBase indexReader,Directory dir,FieldInfos fieldInfos,SegmentInfo info,PostingsReaderBase postingsReader,IOContext context,int termsCacheSize,String segmentSuffix) throws IOException {
  this.postingsReader=postingsReader;
  termsCache=new DoubleBarrelLRUCache<FieldAndTerm,BlockTermState>(termsCacheSize);
  in=dir.openInput(IndexFileNames.segmentFileName(info.name,segmentSuffix,BlockTermsWriter.TERMS_EXTENSION),context);
  boolean success=false;
  try {
    version=readHeader(in);
    postingsReader.init(in);
    seekDir(in,dirOffset);
    final int numFields=in.readVInt();
    if (numFields < 0) {
      throw new CorruptIndexException("invalid number of fields: " + numFields + " (resource="+ in+ ")");
    }
    for (int i=0; i < numFields; i++) {
      final int field=in.readVInt();
      final long numTerms=in.readVLong();
      assert numTerms >= 0;
      final long termsStartPointer=in.readVLong();
      final FieldInfo fieldInfo=fieldInfos.fieldInfo(field);
      final long sumTotalTermFreq=fieldInfo.getIndexOptions() == IndexOptions.DOCS_ONLY ? -1 : in.readVLong();
      final long sumDocFreq=in.readVLong();
      final int docCount=in.readVInt();
      if (docCount < 0 || docCount > info.getDocCount()) {
        throw new CorruptIndexException("invalid docCount: " + docCount + " maxDoc: "+ info.getDocCount()+ " (resource="+ in+ ")");
      }
      if (sumDocFreq < docCount) {
        throw new CorruptIndexException("invalid sumDocFreq: " + sumDocFreq + " docCount: "+ docCount+ " (resource="+ in+ ")");
      }
      if (sumTotalTermFreq != -1 && sumTotalTermFreq < sumDocFreq) {
        throw new CorruptIndexException("invalid sumTotalTermFreq: " + sumTotalTermFreq + " sumDocFreq: "+ sumDocFreq+ " (resource="+ in+ ")");
      }
      FieldReader previous=fields.put(fieldInfo.name,new FieldReader(fieldInfo,numTerms,termsStartPointer,sumTotalTermFreq,sumDocFreq,docCount));
      if (previous != null) {
        throw new CorruptIndexException("duplicate fields: " + fieldInfo.name + " (resource="+ in+ ")");
      }
    }
    success=true;
  }
  finally {
    if (!success) {
      in.close();
    }
  }
  this.indexReader=indexReader;
}
