/** 
 * Creates a {@link org.apache.lucene.analysis.Analyzer.TokenStreamComponents}which tokenizes all the text in the provided  {@link Reader}.
 * @return A{@link org.apache.lucene.analysis.Analyzer.TokenStreamComponents}built from an  {@link StandardTokenizer} filtered with{@link StandardFilter},  {@link TurkishLowerCaseFilter}, {@link StopFilter},  {@link KeywordMarkerFilter} if a stemexclusion set is provided and  {@link SnowballFilter}.
 */
@Override protected TokenStreamComponents createComponents(String fieldName,Reader reader){
  final Tokenizer source=new StandardTokenizer(matchVersion,reader);
  TokenStream result=new StandardFilter(matchVersion,source);
  result=new TurkishLowerCaseFilter(result);
  result=new StopFilter(matchVersion,result,stopwords);
  if (!stemExclusionSet.isEmpty())   result=new KeywordMarkerFilter(result,stemExclusionSet);
  result=new SnowballFilter(result,new TurkishStemmer());
  return new TokenStreamComponents(source,result);
}
