/** 
 * Add new data to the queue. FIXME extract some method
 */
public boolean add(ChannelMessage msg,Member[] destination,InterceptorPayload payload){
  boolean ok=true;
  if (!enabled) {
    if (log.isInfoEnabled())     log.info("FastQueue.add: queue disabled, add aborted");
    return false;
  }
  lock.lockAdd();
  try {
    if (log.isTraceEnabled()) {
      log.trace("FastQueue.add: starting with size " + size);
    }
    if (checkLock) {
      if (inAdd)       log.warn("FastQueue.add: Detected other add");
      inAdd=true;
      if (inMutex)       log.warn("FastQueue.add: Detected other mutex in add");
      inMutex=true;
    }
    if ((maxQueueLength > 0) && (size >= maxQueueLength)) {
      ok=false;
      if (log.isTraceEnabled()) {
        log.trace("FastQueue.add: Could not add, since queue is full (" + size + ">="+ maxQueueLength+ ")");
      }
    }
 else {
      LinkObject element=new LinkObject(msg,destination,payload);
      if (size == 0) {
        first=last=element;
        size=1;
      }
 else {
        if (last == null) {
          ok=false;
          log.error("FastQueue.add: Could not add, since last is null although size is " + size + " (>0)");
        }
 else {
          last.append(element);
          last=element;
          size++;
        }
      }
    }
    if (first == null) {
      log.error("FastQueue.add: first is null, size is " + size + " at end of add");
    }
    if (last == null) {
      log.error("FastQueue.add: last is null, size is " + size + " at end of add");
    }
    if (checkLock) {
      if (!inMutex)       log.warn("FastQueue.add: Cancelled by other mutex in add");
      inMutex=false;
      if (!inAdd)       log.warn("FastQueue.add: Cancelled by other add");
      inAdd=false;
    }
    if (log.isTraceEnabled())     log.trace("FastQueue.add: add ending with size " + size);
  }
  finally {
    lock.unlockAdd(true);
  }
  return ok;
}
