@Override public void write(Directory directory,String segmentName,FieldInfos infos,IOContext context) throws IOException {
  final String fileName=IndexFileNames.segmentFileName(segmentName,"",FIELD_INFOS_EXTENSION);
  IndexOutput out=directory.createOutput(fileName,context);
  BytesRef scratch=new BytesRef();
  boolean success=false;
  try {
    SimpleTextUtil.write(out,NUMFIELDS);
    SimpleTextUtil.write(out,Integer.toString(infos.size()),scratch);
    SimpleTextUtil.writeNewline(out);
    for (    FieldInfo fi : infos) {
      SimpleTextUtil.write(out,NAME);
      SimpleTextUtil.write(out,fi.name,scratch);
      SimpleTextUtil.writeNewline(out);
      SimpleTextUtil.write(out,NUMBER);
      SimpleTextUtil.write(out,Integer.toString(fi.number),scratch);
      SimpleTextUtil.writeNewline(out);
      SimpleTextUtil.write(out,ISINDEXED);
      SimpleTextUtil.write(out,Boolean.toString(fi.isIndexed()),scratch);
      SimpleTextUtil.writeNewline(out);
      if (fi.isIndexed()) {
        assert fi.getIndexOptions().compareTo(IndexOptions.DOCS_AND_FREQS_AND_POSITIONS) >= 0 || !fi.hasPayloads();
        SimpleTextUtil.write(out,INDEXOPTIONS);
        SimpleTextUtil.write(out,fi.getIndexOptions().toString(),scratch);
        SimpleTextUtil.writeNewline(out);
      }
      SimpleTextUtil.write(out,STORETV);
      SimpleTextUtil.write(out,Boolean.toString(fi.hasVectors()),scratch);
      SimpleTextUtil.writeNewline(out);
      SimpleTextUtil.write(out,PAYLOADS);
      SimpleTextUtil.write(out,Boolean.toString(fi.hasPayloads()),scratch);
      SimpleTextUtil.writeNewline(out);
      SimpleTextUtil.write(out,NORMS);
      SimpleTextUtil.write(out,Boolean.toString(!fi.omitsNorms()),scratch);
      SimpleTextUtil.writeNewline(out);
      SimpleTextUtil.write(out,NORMS_TYPE);
      SimpleTextUtil.write(out,getDocValuesType(fi.getNormType()),scratch);
      SimpleTextUtil.writeNewline(out);
      SimpleTextUtil.write(out,DOCVALUES);
      SimpleTextUtil.write(out,getDocValuesType(fi.getDocValuesType()),scratch);
      SimpleTextUtil.writeNewline(out);
      Map<String,String> atts=fi.attributes();
      int numAtts=atts == null ? 0 : atts.size();
      SimpleTextUtil.write(out,NUM_ATTS);
      SimpleTextUtil.write(out,Integer.toString(numAtts),scratch);
      SimpleTextUtil.writeNewline(out);
      if (numAtts > 0) {
        for (        Map.Entry<String,String> entry : atts.entrySet()) {
          SimpleTextUtil.write(out,ATT_KEY);
          SimpleTextUtil.write(out,entry.getKey(),scratch);
          SimpleTextUtil.writeNewline(out);
          SimpleTextUtil.write(out,ATT_VALUE);
          SimpleTextUtil.write(out,entry.getValue(),scratch);
          SimpleTextUtil.writeNewline(out);
        }
      }
    }
    success=true;
  }
  finally {
    if (success) {
      out.close();
    }
 else {
      IOUtils.closeWhileHandlingException(out);
    }
  }
}
