/** 
 * Get the value of the <code>name</code> property as a <code>long</code>.   If no such property is specified, or if the specified value is not a valid <code>long</code>, then <code>defaultValue</code> is returned.
 * @param name property name.
 * @param defaultValue default value.
 * @return property value as a <code>long</code>, or <code>defaultValue</code>. 
 */
public long getLong(String name,long defaultValue){
  String valueString=get(name);
  if (valueString == null)   return defaultValue;
  try {
    String hexString=getHexDigits(valueString);
    if (hexString != null) {
      return Long.parseLong(hexString,16);
    }
    return Long.parseLong(valueString);
  }
 catch (  NumberFormatException e) {
    return defaultValue;
  }
}
