/** 
 * Initialize the endpoint.
 */
@Override public void init() throws Exception {
  if (initialized)   return;
  serverSock=ServerSocketChannel.open();
  socketProperties.setProperties(serverSock.socket());
  InetSocketAddress addr=(getAddress() != null ? new InetSocketAddress(getAddress(),getPort()) : new InetSocketAddress(getPort()));
  serverSock.socket().bind(addr,getBacklog());
  serverSock.configureBlocking(true);
  serverSock.socket().setSoTimeout(getSocketProperties().getSoTimeout());
  if (acceptorThreadCount == 0) {
    acceptorThreadCount=1;
  }
  if (pollerThreadCount <= 0) {
    pollerThreadCount=1;
  }
  stopLatch=new CountDownLatch(pollerThreadCount);
  if (isSSLEnabled()) {
    String keystorePass=getKeystorePass();
    if (keystorePass == null) {
      keystorePass=JSSESocketFactory.DEFAULT_KEY_PASS;
    }
    char[] passphrase=keystorePass.toCharArray();
    char[] tpassphrase=(getTruststorePass() != null) ? getTruststorePass().toCharArray() : passphrase;
    String ttype=(getTruststoreType() != null) ? getTruststoreType() : getKeystoreType();
    KeyStore ks=KeyStore.getInstance(getKeystoreType());
    ks.load(new FileInputStream(getKeystoreFile()),passphrase);
    KeyStore ts=null;
    if (getTruststoreFile() == null) {
    }
 else {
      ts=KeyStore.getInstance(ttype);
      ts.load(new FileInputStream(getTruststoreFile()),tpassphrase);
    }
    KeyManagerFactory kmf=KeyManagerFactory.getInstance(getAlgorithm());
    kmf.init(ks,passphrase);
    TrustManagerFactory tmf=TrustManagerFactory.getInstance(getAlgorithm());
    tmf.init(ts);
    sslContext=SSLContext.getInstance(getSslProtocol());
    sslContext.init(wrap(kmf.getKeyManagers()),tmf.getTrustManagers(),null);
    SSLSessionContext sessionContext=sslContext.getServerSessionContext();
    if (sessionContext != null) {
      if (getSessionCacheSize() != null) {
        sessionContext.setSessionCacheSize(Integer.parseInt(getSessionCacheSize()));
      }
      if (getSessionTimeout() != null) {
        sessionContext.setSessionTimeout(Integer.parseInt(getSessionTimeout()));
      }
    }
  }
  if (oomParachute > 0)   reclaimParachute(true);
  selectorPool.open();
  initialized=true;
}
